from main import stern
stern.sumAB(a,b)
stern.SealN()
stern.flip()
stern.IPS()
stern.letters()
stern.listletters()
stern.unique()
stern.forelse()
stern.difference()
stern.duplicates()
stern.EVT()
stern.StringConcatenation()
stern.DictionaryGenerators()
stern.Output()
stern.FMDIL()
stern.Kwargs()